==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/SELinuxOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class SELinuxOptionsFluentImpl<A extends SELinuxOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements SELinuxOptionsFluent<A>{

    private String level;
    private String role;
    private String type;
    private String user;

    public SELinuxOptionsFluentImpl(){
    }
    public SELinuxOptionsFluentImpl(SELinuxOptions instance){
            this.withLevel(instance.getLevel()); 
            this.withRole(instance.getRole()); 
            this.withType(instance.getType()); 
            this.withUser(instance.getUser()); 
    }

    public String getLevel(){
            return this.level;
    }

    public A withLevel(String level){
            this.level=level; return (A) this;
    }

    public String getRole(){
            return this.role;
    }

    public A withRole(String role){
            this.role=role; return (A) this;
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public String getUser(){
            return this.user;
    }

    public A withUser(String user){
            this.user=user; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SELinuxOptionsFluentImpl that = (SELinuxOptionsFluentImpl) o;
            if (level != null ? !level.equals(that.level) :that.level != null) return false;
            if (role != null ? !role.equals(that.role) :that.role != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            if (user != null ? !user.equals(that.user) :that.user != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.62-sources.jar: io/fabric8/kubernetes/api/model/SELinuxOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.String;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Object;

public class SELinuxOptionsFluentImpl<A extends SELinuxOptionsFluent<A>> extends BaseFluent<A> implements SELinuxOptionsFluent<A>{

    private String level;
    private String role;
    private String type;
    private String user;

    public SELinuxOptionsFluentImpl(){
    }
    public SELinuxOptionsFluentImpl(SELinuxOptions instance){
            this.withLevel(instance.getLevel()); 
            this.withRole(instance.getRole()); 
            this.withType(instance.getType()); 
            this.withUser(instance.getUser()); 
    }

    public String getLevel(){
            return this.level;
    }

    public A withLevel(String level){
            this.level=level; return (A) this;
    }

    public String getRole(){
            return this.role;
    }

    public A withRole(String role){
            this.role=role; return (A) this;
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public String getUser(){
            return this.user;
    }

    public A withUser(String user){
            this.user=user; return (A) this;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SELinuxOptionsFluentImpl that = (SELinuxOptionsFluentImpl) o;
            if (level != null ? !level.equals(that.level) :that.level != null) return false;
            if (role != null ? !role.equals(that.role) :that.role != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            if (user != null ? !user.equals(that.user) :that.user != null) return false;
            return true;
    }




}
